/*
 *  -------------------------------------------------------------------------------

	This code is licensed under the Apache License, Version 2.0 (the "License"); 
	You may not use this file except in compliance with the License. 

	You may obtain a copy of the License at 

	http://www.apache.org/licenses/LICENSE-2.0 

	Unless required by applicable law or agreed to in writing, software 
	distributed under the License is distributed on an "AS IS" BASIS, 
	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
	See the License for the specific language governing permissions and 
	limitations under the License.
	
 *  -------------------------------------------------------------------------------
 */
package de.thischwa.jii.core;

import static org.junit.Assert.*;

import java.util.Arrays;
import java.util.Collection;
import java.util.List;


import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameters;

import de.thischwa.jii.IDimensionProvider;
import de.thischwa.jii.ImageFileInfo;
import de.thischwa.jii.ImageType;
import de.thischwa.jii.PropertiesHolder;
import de.thischwa.jii.core.ImageInfoWrapper;
import de.thischwa.jii.core.ImageMagickWrapper;
import de.thischwa.jii.core.SimpleImageInfoWrapper;
import de.thischwa.jii.core.iTextImageWrapper;

@RunWith(value = Parameterized.class)
public class TestDimensionProviderWrappers {
	private IDimensionProvider dp;

	public TestDimensionProviderWrappers(IDimensionProvider dp) {
		this.dp = dp;
	}

	@Parameters
	public static Collection<IDimensionProvider[]> data() {
		String commandDirIM = PropertiesHolder.get("im.command");
		IDimensionProvider[][] providers = new IDimensionProvider[][] { 
				{ new ImageMagickWrapper(commandDirIM) }, 
				{ new ImageInfoWrapper() }, 
				{ new SimpleImageInfoWrapper() },
				{ new iTextImageWrapper() },
				{ new ImageIOWrapper() } };
		return Arrays.asList(providers);
	}

	@Test
	public void testGetDimension() throws Exception {
		List<ImageType> supportedImageTypes = Arrays.asList(dp.getSupportedTypes());
		ImageFileInfo[] infos = ImageFileInfo.getAll();
		for (ImageFileInfo info : infos) {
			if (!supportedImageTypes.contains(info.getImageType()))
				continue;
			dp.set(info.getFile());
			assertEquals(info.getFile().getName(), info.getDimension(), dp.getDimension());
			assertEquals(info.getFile().getName(), info.getImageType(), dp.getImageType());
		}
	}
}
